==> schlix-cms-v2.2.2-1.zip: schlix/system/apps/core/blockmanager/uninstall.template.php <==
<?php if (!defined('SCHLIX_VERSION')) die('No Access'); ?>
<?php
/**
 * Core: Block Manager - Main admin view template
 * 
 * Core - Block Manager
 * 
 * @copyright 2019 SCHLIX Web Inc
 *
 * @license SCHLIX Shared Source
 *
 * @package core
 * @version 1.0
 * @author  SCHLIX Web Inc <info@schlix.com>
 * @link    http://www.schlix.com
 */
 if (!defined('SCHLIX_VERSION')) die('No Access'); 
?>
<?php 
    $sanitized_ext_name = strtolower(fget_alphanumeric('name')); 
    $url_return = '';
    $is_from_extgallery = false;
    $ext_exists = $this->extensionExists($sanitized_ext_name);
    if ($ext_exists)
    {
        $url_return = $this->createFriendlyAdminURL('');
        $is_from_extgallery = $this->isInstalledFromExtensionGallery($sanitized_ext_name);
    }
    $ext_icon = $this->getIconURL($sanitized_ext_name);
    
?>
<x-ui:schlix-item-editor data-schlix-controller="SCHLIX.CMS.Core_BlockManagerAdminController" data-main-app-description="<?= sprintf(___('Uninstall %s'), $sanitized_ext_name ) ?>">    

    <?php if ($is_from_extgallery): ?>
    <x-ui:alert type="error">
        <?= ___('This extension must be uninstalled from the Extension Gallery') ?>
    </x-ui:alert>
    <?php elseif ($ext_exists): ?>
        <x-ui:row>
            <?php if ($ext_icon): ?>
            <x-ui:column lg="1" md="2" sm="2" xs="3">
                <div class="float-right pull-right content">
                <img src="<?= $ext_icon ?>" class="img-responsive" />
                </div>
            </x-ui:column>
            <?php endif ?>
            <x-ui:column md="6" sm="6" xs="9" >
                <div class="content">
                    <h3><?= sprintf(___('Are you sure you want to uninstall [%s]'), $sanitized_ext_name) ?>?</h3>
                    <div class="schlix-ajax-output"></div>
                    <x-ui:form-simple-ajax name="uninstall_form"  method="post" data-action="<?= $this->createFriendlyAdminURL("action=confirmuninstall&name={$sanitized_ext_name}"); ?>" enctype="multipart/form-data" >
                        <x-ui:csrf />
                        <x-ui:hidden name="name" value="<?= ___h($sanitized_ext_name) ?>" />
                        <x-ui:textbox type="password" name="password" id="password" label="<?= ___('Please enter your password to authenticate this request') ?>" fonticon="fas fa-lock" />
                        <x-ui:button-ok  type="submit" name="submit" data-form-submit="1" id="btn-uninstall" value="Submit" label="<?= ___('OK') ?>" fonticon="fas fa-check" />
                        <x-ui:link-button-cancel href="<?= $url_return ?>" id="cancel_uninstall_button" data-schlix-command="cancel-save-item" name="btn_cancel"  type="submit" fonticon="fas fa-times" label="<?= ___('Cancel'); ?>" />
                    </x-ui:form-simple-ajax>
                </div>
            </x-ui:column>
        </x-ui:row>
    <?php else: ?>
    <x-ui:alert type="error">
        <?= ___('Invalid extension name') ?>
    </x-ui:alert>
    <?php endif ?>
</x-ui:schlix-item-editor>

==> schlix-cms-v2.2.7-1.zip: schlix/system/apps/core/blockmanager/uninstall.template.php <==
<?php if (!defined('SCHLIX_VERSION')) die('No Access'); ?>
<?php
/**
 * Core: Block Manager - Main admin view template
 * 
 * Core - Block Manager
 * 
 * @copyright 2019 SCHLIX Web Inc
 *
 * @license SCHLIX Shared Source
 *
 * @package core
 * @version 1.0
 * @author  SCHLIX Web Inc <info@schlix.com>
 * @link    http://www.schlix.com
 */
 if (!defined('SCHLIX_VERSION')) die('No Access'); 
?>
<?php 
    $sanitized_ext_name = strtolower(fget_alphanumeric('name')); 
    $url_return = '';
    $is_from_extgallery = false;
    $ext_exists = $this->extensionExists($sanitized_ext_name);
    if ($ext_exists)
    {
        $url_return = $this->createFriendlyAdminURL('');
        $is_from_extgallery = $this->isInstalledFromExtensionGallery($sanitized_ext_name);
    }
    $ext_icon = $this->getIconURL($sanitized_ext_name);
    
?>
<x-ui:schlix-item-editor data-schlix-controller="SCHLIX.CMS.Core_BlockManagerAdminController" data-main-app-description="<?= sprintf(___('Uninstall %s'), $sanitized_ext_name ) ?>">    

    <?php if ($is_from_extgallery): ?>
    <x-ui:alert type="error">
        <?= ___('This extension must be uninstalled from the Extension Gallery') ?>
    </x-ui:alert>
    <?php elseif ($ext_exists): ?>
        <x-ui:row>
            <?php if ($ext_icon): ?>
            <x-ui:column lg="1" md="2" sm="2" xs="3">
                <div class="float-right pull-right content">
                <img src="<?= $ext_icon ?>" class="img-responsive" />
                </div>
            </x-ui:column>
            <?php endif ?>
            <x-ui:column md="6" sm="6" xs="9" >
                <div class="content">
                    <h3><?= sprintf(___('Are you sure you want to uninstall [%s]'), $sanitized_ext_name) ?>?</h3>
                    <div class="schlix-ajax-output"></div>
                    <x-ui:form-simple-ajax name="uninstall_form"  method="post" data-action="<?= $this->createFriendlyAdminURL("action=confirmuninstall&name={$sanitized_ext_name}"); ?>" enctype="multipart/form-data" >
                        <x-ui:csrf />
                        <x-ui:hidden name="name" value="<?= ___h($sanitized_ext_name) ?>" />
                        <x-ui:textbox type="password" name="password" id="password" label="<?= ___('Please enter your password to authenticate this request') ?>" fonticon="fas fa-lock" />
                        <x-ui:button button-type="ok"  type="submit" name="submit" data-form-submit="1" id="btn-uninstall" value="Submit" label="<?= ___('OK') ?>" fonticon="fas fa-check" />
                        <x-ui:link-button button-type="danger"  href="<?= $url_return ?>" id="cancel_uninstall_button" data-schlix-command="cancel-save-item" name="btn_cancel"  type="submit" fonticon="fas fa-times" label="<?= ___('Cancel'); ?>" />
                    </x-ui:form-simple-ajax>
                </div>
            </x-ui:column>
        </x-ui:row>
    <?php else: ?>
    <x-ui:alert type="error">
        <?= ___('Invalid extension name') ?>
    </x-ui:alert>
    <?php endif ?>
</x-ui:schlix-item-editor>
